@@ -1,10 +1,10 @@
 """Implement a serializer for caching data to and from version controlled files."""
 
-import inspect
 import json
 import re
 from collections import defaultdict
 from contextlib import suppress
+from datetime import datetime
 from enum import Enum
 from json import JSONEncoder
 from pathlib import Path, PurePath
@@ -67,11 +67,6 @@ class _CacheAssertSerializer(JSONEncoder):
 
     def default(self, obj: Any) -> Any:
         """Extend default encoder."""
-        if isinstance(obj, (bytes)):
-            return str(obj)
-        if isinstance(obj, (str, bytes, list, dict)):
-            return super().default(obj)
-
         converters = _CONVERTERS.get_lookup().get(type(obj))
         for converter in converters or []:
             with suppress(Unconvertable):
@@ -83,15 +78,12 @@ class _CacheAssertSerializer(JSONEncoder):
                     with suppress(Unconvertable):
                         return converter(obj)
 
-        # Fallback for obj of type "type" (i.e. `MagicMock`)
-        with suppress(Unconvertable):
+        # Fallback for obj of the general type "type" (i.e. `MagicMock` or "Flask")
+        try:
             return _generic_memory_address_serializer(obj)
-
-        if inspect.isclass(obj) or str(type(self)).startswith('<class'):
+        except Unconvertable:
             return str(obj)
 
-        raise Unconvertable(f'Failed to encode `{obj}` ({type(obj)}) with {_CONVERTERS.get_lookup()}')
-
 
 def _generic_memory_address_serializer(obj: Any) -> Any:
     if _RE_MEMORY_ADDRESS.search(str(obj)):
@@ -144,6 +136,8 @@ def _serialize_complex(obj: complex) -> List[float]:
 
 _CONVERTERS.register([complex], _serialize_complex)
 
+_CONVERTERS.register([datetime], str)
+
 with suppress(ImportError):
     from pendulum.datetime import DateTime
     _CONVERTERS.register([DateTime], str)
